@@ -1,4 +1,8 @@
 import builtins
+from .core import save_var, load_var, ri, key, click, getcolor, rc, leftclick, middleclick, rightclick, move, randcolor, rgbcolor, getping, mouseX, mouseY, hidecursor, shapecursor, convert_jpg, upload_gif, show_picture, hide_picture, text_to_speech
+import pygame
+import time
+import builtins
 import tkinter as tk
 from PIL import Image
 import requests
@@ -95,7 +99,40 @@ def show_picture():
     img_turtle.showturtle()
 def hide_picture():
     img_turtle.hideturtle()
+
 def text_to_speech(txt, language, yourMP3name):
+    filename = f"{yourMP3name}.mp3"
     tts = gTTS(text=txt, lang=language)
-    tts.save(f"{yourMP3name}.mp3")
-    playsound.playsound(f"{yourMP3name}.mp3")
+    tts.save(filename)
+
+    pygame.mixer.init()
+    pygame.mixer.music.load(filename)
+    pygame.mixer.music.set_volume(1.0)
+    pygame.mixer.music.play()
+
+    while pygame.mixer.music.get_busy():
+        time.sleep(0.1)
+
+
+builtins.save_var = save_var
+builtins.load_var = load_var
+builtins.ri = ri
+builtins.key = key
+builtins.click = click
+builtins.getcolor = getcolor
+builtins.leftclick = leftclick
+builtins.middleclick = middleclick
+builtins.rightclick = rightclick
+builtins.move = move
+builtins.randcolor = randcolor
+builtins.rgbcolor = rgbcolor
+builtins.getping = getping
+builtins.mouseX = mouseX
+builtins.mouseY = mouseY
+builtins.hidecursor = hidecursor
+builtins.shapecursor = shapecursor
+builtins.convert_jpg = convert_jpg
+builtins.upload_gif = upload_gif
+builtins.show_picture = show_picture
+builtins.hide_picture = hide_picture
+builtins.text_to_speech = text_to_speech
